@@ -1,8 +1,7 @@
-from typing import Optional
+from typing import Optional, List
 
 import aiohttp
 
-from .errors import WordNotFound
 from .http import HTTPClient
 from .meaning import Meaning
 from .phonetic import Phonetic
@@ -12,13 +11,12 @@ from .word import Word
 class Client:
     """The class needed to make requests to the API"""
 
-    __slots__ = ("_http")
+    __slots__ = "_http"
 
     def __init__(self, *, _session: Optional[aiohttp.ClientSession] = None) -> None:
         self._http = HTTPClient(session=_session)
 
-
-    async def get_response(self, word: str) -> list:
+    async def get_response(self, word: str) -> List:
         """A helper method to get the response of the API
 
         Parameters
@@ -38,8 +36,6 @@ class Client:
         """
         return await self._http.get("https://api.dictionaryapi.dev/api/v2/entries/en_US/" + word)
 
-
-
     async def get_word(self, word: str) -> Word:
         """A method to get the information of the whole word
 
@@ -56,8 +52,7 @@ class Client:
         response = await self.get_response(word)
         return Word(response)
 
-
-    async def get_meanings(self, word: str) -> list[Meaning]:
+    async def get_meanings(self, word: str) -> List[Meaning]:
         """A method to get just the definitions of a word
 
         Parameters
@@ -71,10 +66,9 @@ class Client:
             a list of a class containing the definitions
         """
         response = await self.get_response(word)
-        return [Meaning(m) for m in response[0]['meanings']]
+        return [Meaning(m) for m in response[0]["meanings"]]
 
-
-    async def get_phonetics(self, word: str) -> list[Phonetic]:
+    async def get_phonetics(self, word: str) -> List[Phonetic]:
         """A method to get pronunciation related things of a word
 
         Parameters
@@ -90,12 +84,10 @@ class Client:
         response = await self.get_response(word)
         return [Phonetic(p) for p in response[0]["phonetics"]]
 
-
-    async def get_pronunciations(self, word: str) -> list[Phonetic]:
+    async def get_pronunciations(self, word: str) -> List[Phonetic]:
         """Same thing as ``Client.get_phonetics``"""
         await self.get_phonetics(word)
 
-
     async def close(self) -> None:
         """Closes the Client"""
         await self._http.close()
