@@ -7,12 +7,11 @@ from .errors import APIError, WordNotFound
 
 class HTTPClient:
 
-    __slots__ = ("session")
+    __slots__ = "session"
 
     def __init__(self, *, session: Optional[aiohttp.ClientSession] = None) -> None:
         self.session = session or aiohttp.ClientSession()
 
-
     async def get(self, url: str, **kwargs) -> Any:
         async with self.session.get(url, timeout=aiohttp.ClientTimeout(60), **kwargs) as res:
             if not 300 >= res.status >= 200:
@@ -28,7 +27,6 @@ class HTTPClient:
 
         return data
 
-
     async def close(self) -> None:
         if self.session:
             await self.session.close()
